@@ -3,18 +3,18 @@ import sys
 
 def print_info() -> None:
     print(
-        "Type annotations for boto3.CognitoSync 1.17.70\n"
-        "Version:         1.17.70.post2\n"
-        "Builder version: 4.12.0\n"
+        "Type annotations for boto3.CognitoSync 1.17.92\n"
+        "Version:         1.17.92\n"
+        "Builder version: 4.18.1\n"
         "Docs:            https://pypi.org/project/mypy-boto3-cognito-sync/\n"
-        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/cognito-sync.html#CognitoSync\n"
+        "Boto3 docs:      https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/cognito-sync.html#CognitoSync\n"
         "Other services:  https://pypi.org/project/boto3-stubs/\n"
         "Changelog:       https://github.com/vemel/mypy_boto3_builder/releases"
     )
 
 
 def print_version() -> None:
-    print("1.17.70.post2")
+    print("1.17.92")
 
 
 def main() -> None:
